%define	module matplotlib

%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so
# one of: GTK GTKAgg GTKCairo GTK3Agg GTK3Cairo CocoaAgg MacOSX Qt4Agg TkAgg WX WXAgg Agg Cairo GDK PS PDF SVG
%global backend TkAgg
%global with_bundled_fonts 1

Name:           python-%{module}
Version:        3.0.3
Release:        %mkrel 2
Summary:        Matlab-style 2D plotting package for Python
License:        Python and MIT
Group:          Development/Python
URL:            http://matplotlib.org/
Source0:        %{module}-%{version}.tar.xz

BuildRequires:  %{_lib}freetype6-devel
BuildRequires:  %{_lib}png-devel
BuildRequires:  x11-server-xvfb
BuildRequires:  zlib-devel


%description
matplotlib is a Python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. matplotlib can be used in Python
scripts, the python and ipython shell (a la Matlab or Mathematica), web
application servers, and various graphical user interface toolkits.

%package -n python3-%{module}
Summary:        Python 2D plotting library
Group:          Development/Python
BuildRequires:  python3-cairo
BuildRequires:  python3-cycler
BuildRequires:  python3-dateutil
BuildRequires:  python3-devel
BuildRequires:  python3-gobject3-devel
BuildRequires:  python3-kiwisolver
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-pillow
BuildRequires:  python3-pyparsing
BuildRequires:  python3-pytz
BuildRequires:  python3-setuptools

Requires:       fonts-ttf-dejavu
Requires:       python-backports-functools_lru_cache
Requires:       python3-cairo
Requires:       python3-cycler
Requires:       python3-dateutil
Requires:       python3-kiwisolver
Requires:       python3-numpy
Requires:       python3-pyparsing
Requires:       python3-%{module}-tk = %{version}-%{release}

%description -n python3-%{module}
matplotlib is a Python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. matplotlib can be used in Python
scripts, the python and ipython shell (a la Matlab or Mathematica), web
application servers, and various graphical user interface toolkits.

%package -n python3-%{module}-wx
Summary:        wxPython backend for matplotlib
Group:          Development/Python
Requires:       python3-%{module} = %{version}-%{release}
Requires:       wxPython

%description -n python3-%{module}-wx
This package contains the wxPython backend for matplotlib.

%package -n python3-%{module}-doc
Summary:        Documentation for matplotlib
Group:          Development/Python
BuildArch:      noarch

%description -n python3-%{module}-doc
This package contains documentation and sample code for matplotlib.


%package -n python3-%{module}-qt4
Summary:        Qt4 backend for python3-matplotlib
Group:          Development/Python
Requires:       python3-matplotlib = %{version}-%{release}
Requires:       python3-qt4

%description -n python3-%{module}-qt4
%{summary}

%package -n python3-%{module}-qt5
Summary:        Qt5 backend for python3-matplotlib
Group:          Development/Python
Requires:       python3-matplotlib = %{version}-%{release}
Requires:       python3-qt5

%description -n python3-%{module}-qt5
%{summary}.

%package -n python3-%{module}-gtk3
Summary:        GTK3 backend for python3-matplotlib
Group:          Development/Python
Requires:       gtk3
Requires:       python3-gobject3
Requires:       python3-matplotlib = %{version}-%{release}

%description -n python3-%{module}-gtk3
%{summary}

%package -n python3-%{module}-tk
Summary:        Tk backend for python3-matplotlib
Group:          Development/Python
Requires:       python3-matplotlib = %{version}-%{release}
Requires:       tkinter3

%description -n python3-%{module}-tk
%{summary}

%prep
%setup -qn %{module}-%{version}

cat<<EOF >setup.cfg
[packages]
tests = False
toolkits_tests = False
[rc_options]
backend = %{backend}
EOF

%if !%{with_bundled_fonts}
sed -i 's/\(USE_FONTCONFIG = \)False/\1True/' lib/%{module}/font_manager.py
%endif

%build
 %{__python3} setup.py build

%install
export http_proxy=http://127.0.0.1/
 %{__python3} setup.py install -O1 --skip-build --root=%{buildroot}
 %py_byte_compile %{__python3} %{buildroot}%{python3_sitearch}
 chmod +x %{buildroot}%{python3_sitearch}/%{module}/dates.py


%if !%{with_bundled_fonts}
  rm -rf %{buildroot}%{_datadir}/%{module}/mpl-data/fonts
%endif

%files -n python3-%{module}-doc
%doc examples

%files -n python3-%{module}
%doc LICENSE README.rst
%{python3_sitearch}/*
%exclude %{python3_sitearch}/%{module}/backends/backend_qt4.*
%exclude %{python3_sitearch}/%{module}/backends/__pycache__/backend_qt4.*
%exclude %{python3_sitearch}/%{module}/backends/backend_qt4agg.*
%exclude %{python3_sitearch}/%{module}/backends/__pycache__/backend_qt4agg.*
%exclude %{python3_sitearch}/%{module}/backends/backend_qt5.*
%exclude %{python3_sitearch}/%{module}/backends/__pycache__/backend_qt5.*
%exclude %{python3_sitearch}/%{module}/backends/backend_qt5agg.*
%exclude %{python3_sitearch}/%{module}/backends/__pycache__/backend_qt5agg.*
%exclude %{python3_sitearch}/%{module}/backends/backend_gtk*
%exclude %{python3_sitearch}/%{module}/backends/__pycache__/backend_gtk*
%exclude %{python3_sitearch}/%{module}/backends/backend_tkagg.py*
%exclude %{python3_sitearch}/%{module}/backends/__pycache__/backend_tkagg.*
%exclude %{python3_sitearch}/%{module}/backends/tkagg.*
%exclude %{python3_sitearch}/%{module}/backends/__pycache__/tkagg.*
%exclude %{python3_sitearch}/%{module}/backends/_tkagg.*

%files -n python3-%{module}-qt4
%{python3_sitearch}/%{module}/backends/backend_qt4.*
%{python3_sitearch}/%{module}/backends/__pycache__/backend_qt4.*
%{python3_sitearch}/%{module}/backends/backend_qt4agg.*
%{python3_sitearch}/%{module}/backends/__pycache__/backend_qt4agg.*

%files -n python3-%{module}-qt5
%{python3_sitearch}/%{module}/backends/backend_qt5.*
%{python3_sitearch}/%{module}/backends/__pycache__/backend_qt5.*
%{python3_sitearch}/%{module}/backends/backend_qt5agg.*
%{python3_sitearch}/%{module}/backends/__pycache__/backend_qt5agg.*

%files -n python3-%{module}-gtk3
%{python3_sitearch}/%{module}/backends/backend_gtk*
%{python3_sitearch}/%{module}/backends/__pycache__/backend_gtk*

%files -n python3-%{module}-tk
%{python3_sitearch}/%{module}/backends/backend_tkagg.py*
%{python3_sitearch}/%{module}/backends/__pycache__/backend_tkagg.*
%{python3_sitearch}/%{module}/backends/tkagg.*
%{python3_sitearch}/%{module}/backends/__pycache__/tkagg.*
%{python3_sitearch}/%{module}/backends/_tkagg.*

%changelog
* Tue Apr 12 2022 TerryN <terryn94 at gmail.com> 3.0.3-2pclos2022
- rebuild for python 3.10

* Fri May 17 2019 pckg <pckg at email.cz> 3.0.3-1pclos2019
- update + added deps for ver. 3.0
- since version 3.0 only for Python 3

* Sat Apr 21 2018 marcin82 <fixxer1982 at gmail.com> 2.2.2-2pclos2018
- rebuild with numpy 1.14.2

* Sun Apr 08 2018 marcin82 <fixxer1982 at gmail.com> 2.2.2-1pclos2018
- update

* Tue Aug 15 2017 bb2 <bb2> - 1.4.3-2pclos2017
- rebuild against updates

* Fri Jun 26 2015 gseaman <galen.seaman at comcast.net> 1.4.3-1gseaman2015
- rebase for PCLinuxOS from Mageia spec
